@@ -1,6 +1,6 @@
 package org.gcube.portlets.widgets.userselection.client.events;
 
-import org.gcube.portlets.widgets.userselection.shared.UserBean;
+import org.gcube.portlets.widgets.userselection.shared.ItemSelectableBean;
 
 import com.google.gwt.event.shared.GwtEvent;
 
@@ -9,14 +9,14 @@ import com.google.gwt.event.shared.GwtEvent;
 public class SelectedUserEvent  extends GwtEvent<SelectedUserEventHandler> {
 	public static Type<SelectedUserEventHandler> TYPE = new Type<SelectedUserEventHandler>();
 	
-	private UserBean user;
+	private ItemSelectableBean user;
 	
 	
-	public UserBean getSelectedUser() {
+	public ItemSelectableBean getSelectedUser() {
 		return user;
 	}
 	
-	public SelectedUserEvent(UserBean user) {
+	public SelectedUserEvent(ItemSelectableBean user) {
 		this.user = user;
 	}
 
